<?php

class ControladorAccion{

    static public function ctrMostrarAccion($item, $valor){

        $tabla = "accion";

        $respuesta = ModeloAccion::mdlMostrarAccion($tabla,$item,$valor);

        return $respuesta;

    }
	 static public function ctrMostrarAccion1($item, $valor){

        $tabla = "accion";

        $respuesta = ModeloAccion::mdlMostrarAccion1($tabla,$item,$valor);

        return $respuesta;

    }
    
    static public function ctrCrearAccion(){

        if (isset($_POST["nuevoNombre"])) {
            if (preg_match('/[a-zA-Z0-9 ]/', $_POST["nuevoNombre"])) {
                $tabla = "accion";
                $datos = array("nombre" => strtoupper(trim($_POST["nuevoNombre"])));
                $respuesta = ModeloAccion::mdlCrearAccion($tabla, $datos);

                if ($respuesta == "ok") {

                    echo '<script>
					swal({
						type: "success",
						title: "¡Accion ha sido guardado correctamente!",
						showConfirmButton: true,
						confirmButtonText: "Cerrar"
					}).then(function(result){
						if(result.value){
							window.location = "accion";
						}
					});
					</script>';

                }
            }else{
                echo '<script>
					swal({
						type: "error",
						title: "¡Accion no puede ir vacío o llevar caracteres especiales!",
						showConfirmButton: true,
						confirmButtonText: "Cerrar"
					}).then(function(result){
						if(result.value){
							window.location = "accion";
						}
					});
				</script>';
            }
            
        }

    }

    static public function ctrEditarAccion(){
		if(isset($_POST["editarNombre"])){
			if(preg_match('/[a-zA-Z0-9 ]/', $_POST["editarNombre"])){
				$tabla = "accion";
				$datos = array("nombre" => strtoupper(trim($_POST["editarNombre"])),
								"id" => $_POST["idAccion"]);
				$respuesta = ModeloAccion::mdlEditarAccion($tabla, $datos);
				if($respuesta == "ok"){
					echo'<script>
					swal({
						  type: "success",
						  title: "Accion ha sido editado correctamente",
						  showConfirmButton: true,
						  confirmButtonText: "Cerrar"
						  }).then(function(result){
									if (result.value) {
									window.location = "accion";
									}
							})
					</script>';
				}
			}else{

				echo'<script>

					swal({
						  type: "error",
						  title: "¡El nombre no puede ir vacío o llevar caracteres especiales!",
						  showConfirmButton: true,
						  confirmButtonText: "Cerrar"
						  }).then(function(result){
							if (result.value) {
							window.location = "accion";
							}
						})
			  	</script>';
			}

		}

	}

	/*=============================================
	BORRAR ACCION
	=============================================*/

	static public function ctrBorrarAccion(){
		if(isset($_GET["idAccion"])){
			$tabla ="accion";
			$datos = $_GET["idAccion"];
			$respuesta = ModeloAccion::mdlBorrarAccion($tabla, $datos);
			if($respuesta == "ok"){
				echo'<script>
				swal({
					  type: "success",
					  title: "Accion ha sido borrado correctamente",
					  showConfirmButton: true,
					  confirmButtonText: "Cerrar"
					  }).then(function(result){
								if (result.value) {
								window.location = "accion";
								}
							})
				</script>';
			}		
		}
	}

}